"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._ = exports.makeOnDeleteTrigger = exports.makeOnUpdateTrigger = exports.makeOnCreateTrigger = void 0;
const util_1 = require("../util");
const non_testable_1 = require("./non-testable");
/**
 * Type safe and convenience firebase-functions wrapper
 */
function makeDocTriggerPath(collectionName) {
    return `${collectionName}/{documentId}`;
}
function makeDocTrigger(collectionName, options) {
    const functionsFirestore = (0, non_testable_1.getFunctionsFirestore)(options === null || options === void 0 ? void 0 : options.regions);
    const docPath = exports._.makeDocTriggerPath(collectionName);
    const docTrigger = functionsFirestore.document(docPath);
    return docTrigger;
}
function makeOnCreateTrigger(collectionName, handler) {
    return exports._.makeDocTrigger(collectionName).onCreate((snapshot, context) => {
        const wrappedSnapshot = (0, util_1.wrapFirebaseSnapshot)(snapshot);
        const result = handler(wrappedSnapshot, context);
        return result;
    });
}
exports.makeOnCreateTrigger = makeOnCreateTrigger;
function makeOnUpdateTrigger(collectionName, handler) {
    return exports._.makeDocTrigger(collectionName).onUpdate((change, context) => {
        const wrappedChange = (0, util_1.wrapFirebaseChangeSnapshot)(change);
        const result = handler(wrappedChange, context);
        return result;
    });
}
exports.makeOnUpdateTrigger = makeOnUpdateTrigger;
function makeOnDeleteTrigger(collectionName, handler) {
    return exports._.makeDocTrigger(collectionName).onDelete((snapshot, context) => {
        const wrappedSnapshot = (0, util_1.wrapFirebaseSnapshot)(snapshot);
        const result = handler(wrappedSnapshot, context);
        return result;
    });
}
exports.makeOnDeleteTrigger = makeOnDeleteTrigger;
exports._ = { makeDocTrigger, makeDocTriggerPath };
//# sourceMappingURL=index.js.map