import { App } from 'firebase-admin/app';
import { DocumentReference, DocumentSnapshot as FirestoreDocumentSnapshot, FieldValue, QueryDocumentSnapshot } from 'firebase-admin/firestore';
import { Change, CloudFunction, EventContext, firestore, SUPPORTED_REGIONS } from 'firebase-functions';
import { DocumentBuilder } from 'firebase-functions/v1/firestore';
export type { FirestoreDocumentSnapshot, Change, QueryDocumentSnapshot, App, DocumentReference, DocumentBuilder, };
export declare type Dict<T> = {
    readonly [key: string]: T;
};
export declare type StringFieldSpec = {
    readonly type: 'string';
};
export declare type RefIdFieldSpec = {
    readonly type: 'refId';
    readonly refCollection: string;
};
export declare type SrcFieldSpec = StringFieldSpec | RefIdFieldSpec;
export declare type RefSpec = {
    readonly collectionName: string;
    readonly fieldName: string;
};
export declare type JoinSpec = {
    readonly firstRef: RefSpec;
    readonly refChain: readonly RefSpec[];
    readonly selectedFieldNames: readonly string[];
};
export declare type CountSpec = {
    readonly groupBy: string;
    readonly countedCollectionName: string;
};
export declare type ViewSpec = {
    readonly selectedFieldNames: readonly string[];
    readonly joinSpecs: Dict<JoinSpec>;
    readonly countSpecs: Dict<CountSpec>;
};
export declare type CollectionSpec = {
    readonly src: Dict<SrcFieldSpec>;
    readonly views: Dict<ViewSpec>;
};
export declare type FirestoreDataType = string | number;
export declare type FirestoreWriteDataType = FirestoreDataType | FieldValue;
export declare type DocumentData = Dict<FirestoreDataType>;
export declare type WriteDocumentData = Dict<FirestoreWriteDataType>;
export declare type DocumentDataChange = {
    readonly before: DocumentData;
    readonly after: DocumentData;
};
export declare type DocumentChangeSnapshot = {
    readonly id: string;
    readonly data: DocumentDataChange;
};
export declare type DocumentSnapshot = {
    readonly id: string;
    readonly data: DocumentData;
};
export declare type QuerySnapshot = {
    readonly docs: readonly DocumentSnapshot[];
};
export declare type OnCreateTrigger = CloudFunction<firestore.QueryDocumentSnapshot>;
export declare type OnDeleteTrigger = OnCreateTrigger;
export declare type OnUpdateTrigger = CloudFunction<Change<firestore.QueryDocumentSnapshot>>;
export declare type ViewTriggers = {
    readonly onSrcDocCreated: OnCreateTrigger;
    readonly onSrcDocUpdated: OnUpdateTrigger;
    readonly onSrcDocDeleted: OnDeleteTrigger;
    readonly onJoinRefDocUpdated: Dict<OnUpdateTrigger>;
    readonly onCountedDocCreated: Dict<OnCreateTrigger>;
    readonly onCountedDocDeleted: Dict<OnDeleteTrigger>;
};
export declare type CollectionTriggers = {
    readonly onRefDocDeleted: Dict<OnDeleteTrigger | undefined>;
    readonly view: Dict<ViewTriggers>;
};
export declare type OnCreateTriggerHandler = (snapshot: DocumentSnapshot, context: EventContext) => Promise<unknown>;
export declare type OnDeleteTriggerHandler = OnCreateTriggerHandler;
export declare type OnUpdateTriggerHandler = (change: DocumentChangeSnapshot, context: EventContext) => Promise<unknown>;
export declare type GetDocTriggerOptions = {
    readonly regions?: ReadonlyArray<typeof SUPPORTED_REGIONS[number]>;
};
export declare type FunctionsFirestore = {
    readonly document: (path: string) => firestore.DocumentBuilder;
    readonly namespace: (namespace: string) => firestore.NamespaceBuilder;
    readonly database: (database: string) => firestore.DatabaseBuilder;
};
export declare const WHERE_FILTER_OP: readonly ["<", "<=", "==", "!=", ">=", ">", "array-contains", "in", "not-in", "array-contains-any"];
export declare type WhereFilterOp = typeof WHERE_FILTER_OP[number];
//# sourceMappingURL=type.d.ts.map