import { Dict, FirestoreDataType, DocumentDataChange, DocumentData, DocumentSnapshot, FirestoreDocumentSnapshot, Change, DocumentChangeSnapshot, QueryDocumentSnapshot } from './type';
export declare type Mapped<T extends string | number, VResult> = {
    readonly [P in T]: VResult;
};
export declare function mapValues<T extends string | number, V, VResult>(obj: Mapped<T, V>, mapper: (value: V, key: string) => VResult): Mapped<T, VResult>;
/**
 * Throw rejected promises from array of settled promises.
 *
 * @param promiseResults The array of settled promises to process
 */
export declare function throwRejectedPromises(promiseResults: readonly PromiseSettledResult<unknown>[]): void;
/**
 * Create a object by merging array of objects.
 *
 * @param objectArray The array of object to merge.
 * @returns The merged object
 */
export declare function mergeObjectArray<T>(objectArray: readonly {
    readonly [key: string]: T;
}[]): {
    readonly [key: string]: T;
};
/**
 * Create an object with all undefined values removed.
 *
 * @example
 * const obejectWithUndefined = {
 *   definedValue: '',
 *   undefinedValue: undefined
 *  }
 * const result = compactObject(objectWithUndefined)
 * // result => { definedValue: '' }
 *
 *
 * @param object The object to compact.
 * @returns Returns the new object without undefined values.
 */
export declare function compactObject<T>(object: Dict<T | undefined>): Dict<T>;
/**
 * Get value difference before and after a change.
 * Returns undefined if value not changed.
 *
 * @example
 * const change1 = getValueChange('foo', 'bar')
 * // change1 => 'bar'
 *
 * @example
 * const change2 = getValueChange('lorem', 'lorem')
 * // change2 => undefined
 *
 * @param beforeValue Value before change.
 * @param afterValue Value after change.
 * @returns Difference between before and after.
 */
export declare function getValueChange(beforeValue: FirestoreDataType, afterValue: FirestoreDataType): FirestoreDataType | undefined;
/**
 *
 * @param documentDataChange
 * @returns
 */
export declare function getDocDataChange({ before, after, }: DocumentDataChange): DocumentData;
export declare function getViewCollectionName(collectionName: string, viewName: string): string;
export declare function wrapFirebaseSnapshot(snapshot: FirestoreDocumentSnapshot): DocumentSnapshot;
export declare function wrapFirebaseChangeSnapshot(change: Change<QueryDocumentSnapshot>): DocumentChangeSnapshot;
//# sourceMappingURL=util.d.ts.map