"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports._ = exports.materializeCountViewData = exports.onCountedDocDeleted = exports.onCountedDocCreated = void 0;
const firebase_admin_1 = require("./firebase-admin");
const firebase_functions_1 = require("./firebase-functions");
const util_1 = require("./util");
function getStringField(data, fieldName) {
    const fieldValue = data[fieldName];
    if (typeof fieldValue !== 'string') {
        throw Error(`Invalid Type: ${JSON.stringify({ data, fieldName })}`);
    }
    return fieldValue;
}
function makeIncrementDocData(countName, value) {
    return {
        [countName]: firebase_admin_1.firestore.FieldValue.increment(value),
    };
}
function makeOnCountedDocCreatedTrigger(app, counterCollectionName, viewName, countName, { groupBy: counterRefIdFieldName }) {
    return async (snapshot) => {
        const counterDocId = exports._.getStringField(snapshot.data, counterRefIdFieldName);
        const viewCollectionName = (0, util_1.getViewCollectionName)(counterCollectionName, viewName);
        const incrementedData = exports._.makeIncrementDocData(countName, 1);
        await (0, firebase_admin_1.updateDoc)(app, viewCollectionName, counterDocId, incrementedData);
    };
}
function onCountedDocCreated(app, counterCollectionName, viewName, countSpecs) {
    return (0, util_1.mapValues)(countSpecs, (countSpec, countName) => {
        const handler = makeOnCountedDocCreatedTrigger(app, counterCollectionName, viewName, countName, countSpec);
        const trigger = (0, firebase_functions_1.makeOnCreateTrigger)(countSpec.countedCollectionName, handler);
        return trigger;
    });
}
exports.onCountedDocCreated = onCountedDocCreated;
function makeOnCountedDocDeletedHandler(app, counterCollectionName, viewName, countName, counterRefIdFieldName) {
    return async (snapshot) => {
        const counterDocId = exports._.getStringField(snapshot.data, counterRefIdFieldName);
        const viewCollectionName = (0, util_1.getViewCollectionName)(counterCollectionName, viewName);
        const decrementedData = exports._.makeIncrementDocData(countName, -1);
        await (0, firebase_admin_1.updateDoc)(app, viewCollectionName, counterDocId, decrementedData).catch((reason) => {
            if (reason.code === firebase_admin_1.firestore.GrpcStatus.NOT_FOUND) {
                // Ignore if counter document not exists.
                return;
            }
            throw reason;
        });
    };
}
function onCountedDocDeleted(app, counterCollectionName, viewName, countSpecs) {
    return (0, util_1.mapValues)(countSpecs, (countSpec, countName) => {
        const handler = exports._.makeOnCountedDocDeletedHandler(app, counterCollectionName, viewName, countName, countSpec.groupBy);
        const trigger = (0, firebase_functions_1.makeOnDeleteTrigger)(countSpec.countedCollectionName, handler);
        return trigger;
    });
}
exports.onCountedDocDeleted = onCountedDocDeleted;
function materializeCountViewData(countSpecs) {
    return (0, util_1.mapValues)(countSpecs, () => 0);
}
exports.materializeCountViewData = materializeCountViewData;
exports._ = {
    makeOnCountedDocDeletedHandler,
    makeOnCountedDocCreatedTrigger,
    makeIncrementDocData,
    getStringField,
};
//# sourceMappingURL=view-count.js.map