import { App, Dict, DocumentData, JoinSpec, OnUpdateTrigger } from './type';
/**
 * Maps array of join view specification into array of materialized data.
 *
 * @param app Firebase app.
 * @param srcDocData Source document data of the join view.
 * @param specs Array of join view specification.
 * @returns Array of materialized datas.
 */
export declare function materializeJoinViewData(app: App, srcDocData: DocumentData, specs: Dict<JoinSpec>): Promise<DocumentData>;
/**
 * Create triggers that run on update of documents that referenecd by a
 * collection's join views.
 *
 * @param app Firebase app.
 * @param collectionName Name of the collection.
 * @param viewName Name of the view.
 * @param joinSpecs Specifications of the collection's join views.
 * @returns Dictionary of triggers that run on join view's referenced document
 * updated.
 */
export declare function onJoinRefDocUpdated(app: App, collectionName: string, viewName: string, joinSpecs: Dict<JoinSpec>): Dict<OnUpdateTrigger>;
//# sourceMappingURL=view-join.d.ts.map